//
function doCreate(action, message) {
    //
    var form = document.input;
    if (form == null) {
        return;
    }
    //
    if (!confirm(message)) {
        return;
    }
    //
    form.operation.value = "create";
    //
    form.elements[action].value = "true";
    //
    form.submit();
}
